sippet v0.1.9 Sippet.Transport.UDP.Plug
Summary
Functions
Invoked to check if this connection is reliable (connection-oriented). If
false then the Sippet.Transaction has to retransmit requests or handle
request retransmissions
Invoked to send a message to the network. If any error occur while sending
the message, and the transaction is not nil, the transaction should be
informed so by calling error/2
Starts the UDP plug
Functions
Invoked to check if this connection is reliable (connection-oriented). If
false then the Sippet.Transaction has to retransmit requests or handle
request retransmissions.
Callback implementation for Sippet.Transport.Plug.reliable?/0.
Invoked to send a message to the network. If any error occur while sending
the message, and the transaction is not nil, the transaction should be
informed so by calling error/2.
Callback implementation for Sippet.Transport.Plug.send_message/4.